@@ -1,14 +1,11 @@
 package Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup;
 
-# TODO: this or parts of this may no longer be necessary as of
-# Pod::Markdown 1.400
-
 use strict;
 use warnings;
 use Moose;
 
 # ABSTRACT: add a travis status button to the README.md file
-our $VERSION = '1.70'; # VERSION
+our $VERSION = '1.72'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterBuild';
@@ -28,11 +25,6 @@ sub after_build
     my $content = $readme->slurp;
     $content =~ s{# NAME\s+(.*?) - (.*?#)}{# $1$status\n\n$2}s;
     $content =~ s{# VERSION\s+version (\d+\.|)\d+\.\d+(\\_\d+|)\s+#}{#};
-    # do this twice because the pattern may overlap
-    # TODO: this is not actually enough I think a fix to Pod::Markdown
-    # or using a different converter all together may be required
-    $content =~ s{^(    .*\n    [ \t]*\n)\n(    )}{$1$2}mg;
-    $content =~ s{^(    .*\n    [ \t]*\n)\n(    )}{$1$2}mg;
     $readme->spew($content);
   }
   else
@@ -57,7 +49,7 @@ Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup - add a travis status but
 
 =head1 VERSION
 
-version 1.70
+version 1.72
 
 =head1 SYNOPSIS
 
