@@ -6,9 +6,10 @@ use PerlX::Maybe qw( maybe );
 use Path::Class::File;
 use YAML ();
 use Term::ANSIColor ();
+use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.70'; # VERSION
+our $VERSION = '1.72'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -53,7 +54,6 @@ sub configure
     if -r "inc/run/test.pl";
 
   $self->add_plugins(
-    'Author::Plicease::FiveEight',
     ['GatherDir' => { exclude_filename => [qw( Makefile.PL Build.PL cpanfile )],
                       exclude_match => '^_build/' }, ],
     [ PruneCruft => { except => '.travis.yml' } ],
@@ -91,15 +91,9 @@ sub configure
     }
   };
   
-  $self->add_plugins(
-    'Manifest',
-    'TestRelease',
-  );
-  
-  
   $self->add_plugins(qw(
-
-    Author::Plicease::PrePodWeaver
+    Manifest
+    TestRelease
     PodWeaver
   ));
   
@@ -114,18 +108,31 @@ sub configure
 
   if($] >= 5.010000 && $^O ne 'MSWin32')
   {
-    $self->add_bundle('Git' => {
-      allow_dirty => [ qw( dist.ini Changes README.md ), @{ $self->payload->{allow_dirty} || [] } ],
-    });
+    my $dirty = { allow_dirty => [ qw( dist.ini Changes README.md ), @{ $self->payload->{allow_dirty} || [] } ] };
+    
+    $self->add_plugins(
+      [ 'Git::Check',  $dirty ],
+      [ 'Git::Commit', $dirty ],
+      [ 'Git::Tag'            ],
+      [ 'Git::Push'           ],
+    );
   }
 
-  $self->add_plugins([
-    'Author::Plicease::Resources' => {
-      maybe github_user => $self->payload->{github_user},
-      maybe github_repo => $self->payload->{github_repo},
-      maybe homepage    => $self->payload->{homepage},
-    },
-  ]);
+  do {
+    my $name = dir->absolute->basename;
+    my $user = $self->payload->{github_user} || 'plicease';
+    my $repo = $self->payload->{github_repo} || $name;
+  
+    $self->add_plugins([
+      'MetaResources' => {
+        'homepage' => $self->payload->{homepage} || "http://perl.wdlabs.com/$name",
+        'bugtracker.web'  => sprintf("https://github.com/%s/%s/issues", $user, $repo),
+        'repository.url'  => sprintf("git://github.com/%s/%s.git",      $user, $repo),
+        'repository.web'  => sprintf("https://github.com/%s/%s",        $user, $repo),
+        'repository.type' => 'git',
+      },
+    ]);
+  };
 
   if($self->payload->{release_tests})
   {
@@ -169,8 +176,6 @@ sub configure
     },
   ]);
 
-  $self->add_plugins(qw( Author::Plicease::Recommend ));
-  
   $self->add_plugins([
     'Prereqs' => 'NeedTestMore094' => {
       '-phase'     => 'test',
@@ -237,7 +242,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.70
+version 1.72
 
 =head1 SYNOPSIS
 
@@ -247,16 +252,53 @@ In your dist.ini:
 
 =head1 DESCRIPTION
 
-This Dist::Zilla plugin bundle is mostly equivalent to
+This is a L<Dist::Zilla> plugin bundle is a set of my personal preferences.
+You are probably reading this documentation not out of choice, but because
+you have to.  Sorry.
+
+=over 4
+
+=item Taking over one of my modules?
+
+This dist comes with a script in C<example/unbundle.pl>, which will extract
+the C<@Author::Plicease> portion of the dist.ini configuration so that you
+can edit it and make your own.  I strongly encourage you to do this, as it
+will help you remove the preferences from the essential items.
+
+=item Want to submit a patch for one of my modules?
+
+Consider using C<prove -l> on the test suite or adding the lib directory
+to C<PERL5LIB>.  Save yourself the hassle of dealing with L<Dist::Zilla>
+at all.  If there is something wrong with one of the generated files
+(such as C<Makefile.PL> or C<Build.PL>) consider opening a support ticket
+instead.  Most other activities that you relating to the use of L<Dist::Zilla>
+have to do with release testing and uploading to CPAN which is more
+my responsibility than yours.
+
+=item Really need to fix some aspect of the build process?
+
+Or perhaps the module in question is using XS (hint: convert it to FFI
+instead!).  If you really do need to fix some aspect of the build process
+then you probably do need to install L<Dist::Zilla> and this bundle.
+If you are having trouble figuring out how it works, then try extracting
+the bundle using the C<example/unbundle.pl> script mentioned above.
+
+=back
+
+I've only uploaded this to CPAN to assist others who may be working on
+one of my dists.  I don't expect anyone to use it for their own projects.
+
+This plugin bundle is mostly equivalent to
 
- # Basic - UploadToCPAN, Readme, ExtraTests, and ConfirmRelease
  [GatherDir]
  exclude_filename = Makefile.PL
  exclude_filename = Build.PL
  exclude_filename = cpanfile
- exclude_match    = ^_build/
+ exclude_match = ^_build/
+ 
  [PruneCruft]
  except = .travis.yml
+ 
  [ManifestSkip]
  [MetaYAML]
  [License]
@@ -265,44 +307,57 @@ This Dist::Zilla plugin bundle is mostly equivalent to
  [MakeMaker]
  [Manifest]
  [TestRelease]
- 
- [Author::Plicease::PrePodWeaver]
  [PodWeaver]
+ 
  [NextRelease]
  format = %-9v %{yyyy-MM-dd HH:mm:ss Z}d
+ 
  [AutoPrereqs]
  [OurPkgVersion]
  [MetaJSON]
  
- [@Git]
+ [Git::Check]
  allow_dirty = dist.ini
  allow_dirty = Changes
  allow_dirty = README.md
  
- [Author::Plicease::Resources]
+ [Git::Commit]
+ allow_dirty = dist.ini
+ allow_dirty = Changes
+ allow_dirty = README.md
+ 
+ [Git::Tag]
+ [Git::Push]
+ 
+ [MetaResources]
+ bugtracker.web = https://github.com/plicease/My-Dist/issues
+ homepage = http://perl.wdlabs.com/My-Dist
+ repository.type = git
+ repository.url = git://github.com/plicease/My-Dist.git
+ repository.web = https://github.com/plicease/My-Dist
+ 
  [InstallGuide]
  [MinimumPerl]
- [ConfirmRelease] 
+ [ConfirmRelease]
  
  [ReadmeAnyFromPod]
- type     = text
  filename = README
  location = build
+ type = text
  
  [ReadmeAnyFromPod / ReadMePodInRoot]
- type     = markdown
  filename = README.md
  location = root
+ type = markdown
  
  [Author::Plicease::MarkDownCleanup]
- [Author::Plicease::Recommend]
+ travis_status = 0
  
  [Prereqs / NeedTestMore094]
- ; for subtest
- -phase     = test
+ -phase = test
  Test::More = 0.94
  
- [SpecialPrereqs]
+ [Author::Plicease::SpecialPrereqs]
  [CPANFile]
 
 Some exceptions:
@@ -311,13 +366,13 @@ Some exceptions:
 
 =item Perl 5.8
 
-L<[@Git]|Dist::Zilla::PluginBundle::Git> does not support Perl 5.8, so it
+C<Dist::Zilla::Plugin::Git::*> does not support Perl 5.8, so it
 is not a prereq there, and it isn't included in the bundle.  As a result
 releasing from Perl 5.8 is not allowed.
 
 =item MSWin32
 
-Installing L<[@Git]|Dist::Zilla::PluginBundle::Git> on MSWin32 is a pain
+Installing L<Dist::Zilla::Plugin::Git::*> on MSWin32 is a pain
 so it is also not a prereq on that platform, isn't used and as a result
 releasing from MSWin32 is not allowed.
 
@@ -386,11 +441,6 @@ to install L<Dist::Zilla> and L<Dist::Zilla::PluginBundle::Author::Plicease>.
 
 Additional dirty allowed file passed to @Git.
 
-=head1 SEE ALSO
-
-L<Author::Plicease::Init|Dist::Zilla::Plugin::Author::Plicease::Init>,
-L<MintingProfile::Plicease|Dist::Zilla::MintingProfile::Author::Plicease>
-
 =head1 AUTHOR
 
 Graham Ollis <perl@cpan.org>
